@@ -143,6 +143,40 @@ def del_conformers(basename: str):
 # @app.command()
 
 
+def zip_attachment(mole_name):
+    '''
+    '''
+    import zipfile
+    import tempfile
+    newname = os.path.join(mole_name,mole_name + '.zip')
+    # zipdir=os.path.join(, 'archives')
+    zipdir = os.path.join(mole_name)
+    # if not os.path.exists(newname):
+    archivefile = tempfile.mktemp(dir=zipdir)
+    f = zipfile.ZipFile(archivefile, 'w', zipfile.ZIP_DEFLATED)
+    # datapath = os.path.join(DATABANK_PATH, 'data')
+    # with cd(datapath):
+        # startdir = molecule.molecule_name
+        # for dirpath, dirnames, filenames in os.walk(startdir):
+    for filename in os.listdir(mole_name):
+        if filename.endswith('dihedra_list') or filename.endswith('uni_diha_list') or filename.endswith('.pdf') \
+            or filename.endswith('.docx') or filename.endswith('.xlsx') :
+            f.write(os.path.join(mole_name,filename))
+    f.close()
+    base = os.path.basename(archivefile)
+    dir = os.path.dirname(archivefile)
+    os.rename(archivefile, newname)
+    payload={
+        'file': newname,
+        'type': 'application/zip'
+    }
+    with open(newname,'rb') as file:
+        r = requests.post(API_ADDRESS+'/attachment/'+mole_name, data=file)
+    # print(r.text)
+
+    os.remove(newname)
+       
+
 def put_conformers(folder: str):
     mole_name = os.path.basename(folder).strip()
     conf_list = []
@@ -191,6 +225,7 @@ def put_conformers(folder: str):
 
     r = requests.post(API_ADDRESS+'/put_conformers/', data=json.dumps(payload))
     if r.text == 'ok':
+        zip_attachment(folder)
         return "ok"
     elif r.text == 'error':
         print("molecule "+mole_name + " already exists")
@@ -220,7 +255,7 @@ def put(mole_folder: str):
 
 
 @app.command()
-def delete(mole_name: str):
+def rm(mole_name: str):
     return del_conformers(mole_name)
 
 
@@ -228,6 +263,35 @@ def delete(mole_name: str):
 def get(mole_folder: str):
     return get_conformers(mole_folder)
 
+def unzip(filename):
+    import zipfile
+    with zipfile.ZipFile(filename, 'r') as zip_ref:
+        zip_ref.extractall(os.path.curdir)
+@app.command()
+def get_att(mole_name_folder: str):
+    folder = os.path.exists(mole_name_folder)
+    if not folder:
+        os.makedirs(mole_name_folder)
+    (dirname, basename) = parse_folder_name(mole_name_folder)
+    payload = {'mole_name': basename}
+    
+    
+    r = requests.get(API_ADDRESS+'/get_att/', params=payload, stream=True)
+       
+    if r.text == 'error':
+        print("molecule " + basename+" does not have attachments in database")
+        exit(-1)
+        return "error" 
+    os.chdir(dirname)
+    # print(dirname)
+    # print(basename)
+    with open(basename+'.zip','wb') as f:
+        f.write(r.content)
+    
+    unzip(basename+'.zip')
+    os.remove(basename+'.zip')
+
+
 
 @app.command()
 def get_by_energy(mole_folder: str, energy_level: float):
@@ -256,7 +320,7 @@ def trans(folder):
         os.system('rm *.out')
         os.system('mkdir xyzfiles')
         os.system('mv *.xyz xyzfiles/')
-
+    print('transformed.')
 
 if __name__ == "__main__":
     app()
